
#ifndef SI_PREFIX_H
#define SI_PREFIX_H


/** si prefix for number */
typedef struct
{
    char pref[2];	/* prefix as string (may be empty) */
    double factor;	/* factor of the prefix: 1000 for "k" */
    int prec;		/* precision: number of decimal digits */
} t_si_prefix;


/**
 * determine Si prefix
 *
 * x	    number
 * d	    number of significant digits
 * return: prefix and factor
 */
t_si_prefix si_prefix( double x, int d );


/**
 * format quantity: number and unit
 *
 * The return string varies in length. Due to utf8-chars the lenght does not
 * correspond to positions on screen.
 * '-0.00 µOhm'
 * '-00.0 MS'
 *
 * x	    number
 * p	    SI prefix
 * u	    unit, at most three chars
 * return: string in static buffer
 *         The buffer is overwritten at the next call.
 */
char * format_si( double x, t_si_prefix p, const char * u );


/**
 * read number and SI-prefix
 *
 * Read a string like "100 k" as 1e5.
 * 
 * s	    string
 * return: number
 */
double scan_si( const char * s );


#endif
